<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>AnnsActionDialog</name>
    <message>
        <location filename="../src/AnnsActionDialog.ui" line="14"/>
        <source>New Annotations Action</source>
        <translation>Yeni Ek Açıklamalar Eylemi</translation>
    </message>
    <message>
        <location filename="../src/AnnsActionDialog.ui" line="34"/>
        <source>Merge into one annotation table</source>
        <translation>Tek bir ek açıklama tablosunda birleştirin</translation>
    </message>
    <message>
        <location filename="../src/AnnsActionDialog.ui" line="53"/>
        <source>Shift annotations using
this merge sequence slot:</source>
        <translation>Ek açıklamaları kullanarak kaydırın
bu birleştirme sırası yuvası:</translation>
    </message>
    <message>
        <location filename="../src/AnnsActionDialog.ui" line="64"/>
        <source>Filter duplicated annotations</source>
        <translation>Yinelenen ek açıklamaları filtrele</translation>
    </message>
</context>
<context>
    <name>BreakpointHitCountDialog</name>
    <message>
        <location filename="../src/BreakpointHitCountDialog.ui" line="26"/>
        <source>Breakpoint Hit Count</source>
        <translation>Kesme Noktası Vuruş Sayısı</translation>
    </message>
    <message>
        <location filename="../src/BreakpointHitCountDialog.ui" line="50"/>
        <source>When the breakpoint is h&amp;it:</source>
        <translation>Kesme noktasına u&amp;laşıldığında:</translation>
    </message>
    <message>
        <location filename="../src/BreakpointHitCountDialog.ui" line="89"/>
        <source>Current hit count:</source>
        <translation>Mevcut isabet sayısı:</translation>
    </message>
    <message>
        <location filename="../src/BreakpointHitCountDialog.ui" line="96"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../src/BreakpointHitCountDialog.ui" line="43"/>
        <source>A breakpoint is hit when the breakpoint location is reached and the condition is&lt;br&gt;satisfied. The hit count is the number of times the breakpoint has been hit.</source>
        <translation>Kesme noktası konumuna ulaşıldığında ve koşul karşılandığında&lt;br&gt;bir kesme noktasına ulaşılır. Hit sayısı, kesme noktasının kaç kez vurulduğudur.</translation>
    </message>
</context>
<context>
    <name>CreateDirectoryDialog</name>
    <message>
        <location filename="../src/CreateDirectoryDialog.ui" line="14"/>
        <source>Create a directory</source>
        <translation>Bir dizin oluşturun</translation>
    </message>
    <message>
        <location filename="../src/CreateDirectoryDialog.ui" line="43"/>
        <source>Parent directory:</source>
        <translation>Ana Dizin:</translation>
    </message>
    <message>
        <location filename="../src/CreateDirectoryDialog.ui" line="63"/>
        <source>Name:</source>
        <translation>Ad:</translation>
    </message>
</context>
<context>
    <name>DatasetWidget</name>
    <message>
        <location filename="../src/DatasetWidget.ui" line="20"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <location filename="../src/DatasetWidget.ui" line="40"/>
        <source>Add file(s)</source>
        <translation>Dosya ekle</translation>
    </message>
    <message>
        <location filename="../src/DatasetWidget.ui" line="62"/>
        <source>Add directory</source>
        <translation>Dizin ekle</translation>
    </message>
    <message>
        <location filename="../src/DatasetWidget.ui" line="116"/>
        <source>Up url(s)</source>
        <translation>Yukarı url&apos;ler</translation>
    </message>
    <message>
        <location filename="../src/DatasetWidget.ui" line="141"/>
        <source>Down url(s)</source>
        <translation>Aşağı URL&apos;ler</translation>
    </message>
    <message>
        <location filename="../src/DatasetWidget.ui" line="166"/>
        <source>Delete urls(s)</source>
        <translation>URL&apos;leri silin</translation>
    </message>
</context>
<context>
    <name>DbFolderOptions</name>
    <message>
        <location filename="../src/DbFolderOptions.ui" line="32"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <location filename="../src/DbFolderOptions.ui" line="50"/>
        <source>Recursive</source>
        <translation>Özyinelemeli</translation>
    </message>
</context>
<context>
    <name>DirectoryOptions</name>
    <message>
        <location filename="../src/DirectoryOptions.ui" line="32"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <location filename="../src/DirectoryOptions.ui" line="46"/>
        <source>Exclude mask</source>
        <translation>Maskeyi hariç tut</translation>
    </message>
    <message>
        <location filename="../src/DirectoryOptions.ui" line="75"/>
        <source>Inсlude mask</source>
        <translation>Maske dahil et</translation>
    </message>
    <message>
        <location filename="../src/DirectoryOptions.ui" line="112"/>
        <source>Recursive</source>
        <translation>Özyinelemeli</translation>
    </message>
</context>
<context>
    <name>EditBreakpointLabelsDialog</name>
    <message>
        <location filename="../src/EditBreakpointLabelsDialog.ui" line="60"/>
        <source>O&amp;r choose among existing labels</source>
        <translation>V&amp;eya mevcut etiketler arasından seçim yapın</translation>
    </message>
    <message>
        <location filename="../src/EditBreakpointLabelsDialog.ui" line="53"/>
        <source>&amp;Add</source>
        <translation>&amp;Ekle</translation>
    </message>
    <message>
        <location filename="../src/EditBreakpointLabelsDialog.ui" line="26"/>
        <source>Edit Breakpoint Labels</source>
        <translation>Kesme Noktası Etiketlerini Düzenle</translation>
    </message>
    <message>
        <location filename="../src/EditBreakpointLabelsDialog.ui" line="34"/>
        <source>T&amp;ype a new label</source>
        <translation>Yeni bir etiket y&amp;azın</translation>
    </message>
</context>
<context>
    <name>EditFloatMarkerWidget</name>
    <message>
        <location filename="../src/EditFloatMarkerWidget.ui" line="14"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <location filename="../src/EditFloatMarkerWidget.ui" line="20"/>
        <source>Interval:</source>
        <translation>Aralık:</translation>
    </message>
    <message>
        <location filename="../src/EditFloatMarkerWidget.ui" line="42"/>
        <source>..</source>
        <translation>..</translation>
    </message>
    <message>
        <location filename="../src/EditFloatMarkerWidget.ui" line="64"/>
        <source>Less than:</source>
        <translation>Küçüktür:</translation>
    </message>
    <message>
        <location filename="../src/EditFloatMarkerWidget.ui" line="94"/>
        <source>Greater than:</source>
        <translation>Büyüktür:</translation>
    </message>
</context>
<context>
    <name>EditIntegerMarkerWidget</name>
    <message>
        <location filename="../src/EditIntegerMarkerWidget.ui" line="20"/>
        <source>Interval:</source>
        <translation>Aralık:</translation>
    </message>
    <message>
        <location filename="../src/EditIntegerMarkerWidget.ui" line="26"/>
        <location filename="../src/EditIntegerMarkerWidget.ui" line="67"/>
        <location filename="../src/EditIntegerMarkerWidget.ui" line="97"/>
        <source>radioButtonsGroup</source>
        <translation>radyo Düğme Grubu</translation>
    </message>
    <message>
        <location filename="../src/EditIntegerMarkerWidget.ui" line="45"/>
        <source>..</source>
        <translation>..</translation>
    </message>
    <message>
        <location filename="../src/EditIntegerMarkerWidget.ui" line="64"/>
        <source>Less than:</source>
        <translation>Küçüktür:</translation>
    </message>
    <message>
        <location filename="../src/EditIntegerMarkerWidget.ui" line="94"/>
        <source>Greater than:</source>
        <translation>Büyüktür:</translation>
    </message>
</context>
<context>
    <name>EditMarkerDialog</name>
    <message>
        <location filename="../src/EditMarkerDialog.ui" line="14"/>
        <source>Edit Marker</source>
        <translation>İşaretleyici</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerDialog.ui" line="28"/>
        <source>Marker name:</source>
        <translation>İşaretleyici adı:</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerDialog.ui" line="35"/>
        <source>NewMarker</source>
        <translation>Yenişaretleyici</translation>
    </message>
</context>
<context>
    <name>EditMarkerGroupDialog</name>
    <message>
        <location filename="../src/EditMarkerGroupDialog.ui" line="14"/>
        <source>Edit Marker Group</source>
        <translation>İşaretçi Grubunu Düzenle</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.ui" line="22"/>
        <source>Marker group name:</source>
        <translation>İşaretçi grubu adı:</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.ui" line="29"/>
        <source>NewMarkerGroup</source>
        <translation>Yeni İşaretçi Grubu</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.ui" line="36"/>
        <source>Marker group type:</source>
        <translation>İşaretçi grubu türü:</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.ui" line="46"/>
        <source>Parameter:</source>
        <translation>Parametre:</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.ui" line="60"/>
        <source>Add</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.ui" line="80"/>
        <source>Edit</source>
        <translation>Düzenle</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.ui" line="87"/>
        <source>Remove</source>
        <translation>Kaldır</translation>
    </message>
</context>
<context>
    <name>EditStringMarkerWidget</name>
    <message>
        <location filename="../src/EditStringMarkerWidget.ui" line="14"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <location filename="../src/EditStringMarkerWidget.ui" line="20"/>
        <source>Starts with</source>
        <translation>İle başlar</translation>
    </message>
    <message>
        <location filename="../src/EditStringMarkerWidget.ui" line="26"/>
        <location filename="../src/EditStringMarkerWidget.ui" line="39"/>
        <location filename="../src/EditStringMarkerWidget.ui" line="52"/>
        <location filename="../src/EditStringMarkerWidget.ui" line="65"/>
        <source>buttonGroup</source>
        <translation>buttonGroup</translation>
    </message>
    <message>
        <location filename="../src/EditStringMarkerWidget.ui" line="36"/>
        <source>Ends with</source>
        <translation>İle biter</translation>
    </message>
    <message>
        <location filename="../src/EditStringMarkerWidget.ui" line="49"/>
        <source>Contains</source>
        <translation>İçerir</translation>
    </message>
    <message>
        <location filename="../src/EditStringMarkerWidget.ui" line="62"/>
        <source>Regular expression</source>
        <translation>Düzenli ifade</translation>
    </message>
</context>
<context>
    <name>GrouperEditorWidget</name>
    <message>
        <location filename="../src/GrouperEditorWidget.ui" line="14"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <location filename="../src/GrouperEditorWidget.ui" line="22"/>
        <source>Group slot</source>
        <translation>Grup yuvası</translation>
    </message>
    <message>
        <location filename="../src/GrouperEditorWidget.ui" line="39"/>
        <source>Group operation</source>
        <translation>Grup operasyonu</translation>
    </message>
    <message>
        <location filename="../src/GrouperEditorWidget.ui" line="60"/>
        <source>Add</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <location filename="../src/GrouperEditorWidget.ui" line="80"/>
        <source>Edit</source>
        <translation>Düzenle</translation>
    </message>
    <message>
        <location filename="../src/GrouperEditorWidget.ui" line="87"/>
        <source>Remove</source>
        <translation>Kaldır</translation>
    </message>
</context>
<context>
    <name>MarkerEditorWidget</name>
    <message>
        <location filename="../src/MarkerEditorWidget.ui" line="14"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <location filename="../src/MarkerEditorWidget.ui" line="22"/>
        <source>Add</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <location filename="../src/MarkerEditorWidget.ui" line="42"/>
        <source>Edit</source>
        <translation>Düzenle</translation>
    </message>
    <message>
        <location filename="../src/MarkerEditorWidget.ui" line="49"/>
        <source>Remove</source>
        <translation>Kaldır</translation>
    </message>
</context>
<context>
    <name>MsaActionDialog</name>
    <message>
        <location filename="../src/MsaActionDialog.ui" line="26"/>
        <source>New Alignment Action</source>
        <translation>Yeni Hizalama İşlemi</translation>
    </message>
    <message>
        <location filename="../src/MsaActionDialog.ui" line="34"/>
        <source>Merge into one alignment</source>
        <translation>Tek bir hizalamada birleştirin</translation>
    </message>
    <message>
        <location filename="../src/MsaActionDialog.ui" line="50"/>
        <source>Alignment name</source>
        <translation>Hizalama adı</translation>
    </message>
    <message>
        <location filename="../src/MsaActionDialog.ui" line="60"/>
        <source>Filter duplicated rows</source>
        <translation>Yinelenen satırları filtrele</translation>
    </message>
</context>
<context>
    <name>NewBreakpointDialog</name>
    <message>
        <location filename="../src/NewBreakpointDialog.ui" line="20"/>
        <source>New Breakpoint</source>
        <translation>Yeni Kesme Noktası</translation>
    </message>
    <message>
        <location filename="../src/NewBreakpointDialog.ui" line="28"/>
        <source>Break execution when it reaches this element in the workflow</source>
        <translation>İş akışında bu öğeye ulaştığında yürütmeyi durdur</translation>
    </message>
    <message>
        <location filename="../src/NewBreakpointDialog.ui" line="35"/>
        <source>&amp;Element: </source>
        <translation>&amp;Öğe: </translation>
    </message>
</context>
<context>
    <name>NewGrouperSlotDialog</name>
    <message>
        <location filename="../src/NewGrouperSlotDialog.ui" line="32"/>
        <source>Setup New Data Merge Action</source>
        <translation>Yeni Veri Birleştirme Eylemini Ayarlayın</translation>
    </message>
    <message>
        <location filename="../src/NewGrouperSlotDialog.ui" line="43"/>
        <source>Source data slot</source>
        <translation>Kaynak veri yuvası</translation>
    </message>
    <message>
        <location filename="../src/NewGrouperSlotDialog.ui" line="60"/>
        <source>Name of new slot with merged data</source>
        <translation>Birleştirilmiş verilere sahip yeni alanın adı</translation>
    </message>
</context>
<context>
    <name>OutputFileDialog</name>
    <message>
        <location filename="../src/OutputFileDialog.ui" line="14"/>
        <source>Save file/directory</source>
        <translation>Dosyayı/dizini kaydet</translation>
    </message>
    <message>
        <location filename="../src/OutputFileDialog.ui" line="31"/>
        <source>Create directory</source>
        <translation>Dizin oluştur</translation>
    </message>
    <message>
        <location filename="../src/OutputFileDialog.ui" line="63"/>
        <location filename="../src/OutputFileDialog.ui" line="82"/>
        <source>Save to file system</source>
        <translation>Dosya sistemine kaydet</translation>
    </message>
    <message>
        <location filename="../src/OutputFileDialog.ui" line="126"/>
        <source>Directory:</source>
        <translation>Dizin:</translation>
    </message>
    <message>
        <location filename="../src/OutputFileDialog.ui" line="146"/>
        <source>File name:</source>
        <translation>Dosya adı:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/WorkflowGUIUtils.cpp" line="48"/>
        <source>Select a sample to start</source>
        <translation>Başlamak için bir örnek seçin</translation>
    </message>
    <message>
        <location filename="../src/WorkflowGUIUtils.cpp" line="156"/>
        <source>Double click to load the sample</source>
        <translation>Örneği yüklemek için çift tıklayın</translation>
    </message>
    <message>
        <location filename="../src/DatasetsController.cpp" line="459"/>
        <source>Paired reads</source>
        <translation>Eşleştirilmiş okumalar</translation>
    </message>
    <message>
        <location filename="../src/DatasetsController.cpp" line="461"/>
        <source>file</source>
        <translation>dosya</translation>
    </message>
    <message>
        <location filename="../src/DatasetsController.cpp" line="461"/>
        <source>folder</source>
        <translation>klasör</translation>
    </message>
    <message>
        <location filename="../src/DatasetsController.cpp" line="462"/>
        <source>UGENE has found &quot;%1&quot; on the file system. Do you want to add it as a second %2 with paired reads?</source>
        <translation>UGENE, dosya sisteminde &quot;%1&quot; buldu. Eşleştirilmiş okumalarla ikinci %2 olarak eklemek ister misiniz?</translation>
    </message>
    <message>
        <location filename="../src/EstimationReporter.cpp" line="35"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/EstimationReporter.cpp" line="36"/>
        <source>h</source>
        <translation>h</translation>
    </message>
    <message>
        <location filename="../src/EstimationReporter.cpp" line="51"/>
        <source>Workflow Estimation</source>
        <translation>İş Akışı Tahmini</translation>
    </message>
    <message>
        <location filename="../src/EstimationReporter.cpp" line="52"/>
        <source>Approximate estimation time of the workflow run is </source>
        <translation>İş akışı çalıştırmasının yaklaşık tahmin süresi </translation>
    </message>
    <message>
        <location filename="../src/OutputFileDialog.cpp" line="168"/>
        <location filename="../src/OutputFileDialog.cpp" line="214"/>
        <source>Workflow-run output</source>
        <translation>İş akışı çalıştırma çıktısı</translation>
    </message>
    <message>
        <location filename="../src/wizard/SelectorActors.cpp" line="42"/>
        <location filename="../src/wizard/WizardController.cpp" line="436"/>
        <source>Unknown actor id: %1</source>
        <translation>Bilinmeyen oyuncu kimliği: %1</translation>
    </message>
    <message>
        <location filename="../src/wizard/WizardController.cpp" line="384"/>
        <location filename="../src/wizard/WizardController.cpp" line="391"/>
        <location filename="../src/wizard/WizardController.cpp" line="397"/>
        <location filename="../src/wizard/WizardController.cpp" line="415"/>
        <location filename="../src/wizard/WizardController.cpp" line="470"/>
        <source>Undefined variable: %1</source>
        <translation>Tanımsız değişken: %1</translation>
    </message>
    <message>
        <location filename="../src/wizard/WizardController.cpp" line="423"/>
        <source>Actors selector is already defined: %1</source>
        <translation>Aktör seçici zaten tanımlanmış: %1</translation>
    </message>
    <message>
        <location filename="../src/wizard/WizardController.cpp" line="433"/>
        <source>Unknown actors selector: %1</source>
        <translation>Bilinmeyen aktörler seçici: %1</translation>
    </message>
    <message>
        <location filename="../src/wizard/WizardController.cpp" line="438"/>
        <source>Unknown actors selector value id: %1</source>
        <translation>Bilinmeyen aktörler seçici değer kimliği: %1</translation>
    </message>
    <message>
        <location filename="../src/wizard/WizardPageController.cpp" line="83"/>
        <source>The page is broken. Please, close the wizard and report us the error: ugene@unipro.ru</source>
        <translation>Sayfa bozuldu. Lütfen sihirbazı kapatın ve hatayı bize bildirin: ugene@unipro.ru</translation>
    </message>
</context>
<context>
    <name>SequeceActionDialog</name>
    <message>
        <location filename="../src/SequenceActionDialog.ui" line="32"/>
        <source>New Sequence Action</source>
        <translation>Yeni Sıra Eylemi</translation>
    </message>
    <message>
        <location filename="../src/SequenceActionDialog.ui" line="40"/>
        <source>Merge into one sequence</source>
        <translation>Tek bir dizide birleştirin</translation>
    </message>
    <message>
        <location filename="../src/SequenceActionDialog.ui" line="46"/>
        <location filename="../src/SequenceActionDialog.ui" line="102"/>
        <source>buttonGroup</source>
        <translation>buttonGroup</translation>
    </message>
    <message>
        <location filename="../src/SequenceActionDialog.ui" line="62"/>
        <source>Merged sequence name</source>
        <translation>Birleştirilmiş sıra adı</translation>
    </message>
    <message>
        <location filename="../src/SequenceActionDialog.ui" line="72"/>
        <source>Gap size</source>
        <translation>Boşluk boyutu</translation>
    </message>
    <message>
        <location filename="../src/SequenceActionDialog.ui" line="99"/>
        <source>Merge into alignment</source>
        <translation>Uyum içinde birleştirin</translation>
    </message>
    <message>
        <location filename="../src/SequenceActionDialog.ui" line="118"/>
        <source>Alignment name</source>
        <translation>Hizalama adı</translation>
    </message>
    <message>
        <location filename="../src/SequenceActionDialog.ui" line="128"/>
        <source>Filter duplicated sequences</source>
        <translation>Yinelenen dizileri filtrele</translation>
    </message>
</context>
<context>
    <name>StringActionDialog</name>
    <message>
        <location filename="../src/StringActionDialog.ui" line="26"/>
        <source>New String Action</source>
        <translation>Yeni Dize Eylemi</translation>
    </message>
    <message>
        <location filename="../src/StringActionDialog.ui" line="37"/>
        <source>Merge strings into one string</source>
        <translation>Dizeleri tek bir dizede birleştirin</translation>
    </message>
    <message>
        <location filename="../src/StringActionDialog.ui" line="53"/>
        <source>Separator</source>
        <translation>Ayraç</translation>
    </message>
</context>
<context>
    <name>U2::AnnsActionDialog</name>
    <message>
        <location filename="../src/NewGrouperSlotDialog.cpp" line="106"/>
        <source>OK</source>
        <translation>TAMAM</translation>
    </message>
    <message>
        <location filename="../src/NewGrouperSlotDialog.cpp" line="107"/>
        <source>Cancel</source>
        <translation>Vazgeç</translation>
    </message>
    <message>
        <location filename="../src/NewGrouperSlotDialog.cpp" line="109"/>
        <source>Don&apos;t shift</source>
        <translation>Kayma</translation>
    </message>
</context>
<context>
    <name>U2::BadgeLabel</name>
    <message>
        <location filename="../src/dashboard/ExternalToolsDashboardWidget.cpp" line="483"/>
        <source>Copy command line</source>
        <translation>Komut satırını kopyala</translation>
    </message>
</context>
<context>
    <name>U2::BowtieWidgetController</name>
    <message>
        <location filename="../src/wizard/BowtieWidgetController.cpp" line="68"/>
        <source>Select
bowtie index file</source>
        <translation>Seçiniz
papyon indeks dosyası</translation>
    </message>
    <message>
        <location filename="../src/wizard/BowtieWidgetController.cpp" line="79"/>
        <source>Select one of Bowtie index files</source>
        <translation>Bowtie dizin dosyalarından birini seçin</translation>
    </message>
</context>
<context>
    <name>U2::BreakpointHitCountDialog</name>
    <message>
        <location filename="../src/BreakpointHitCountDialog.cpp" line="73"/>
        <source>Reset</source>
        <translation>Sıfırla</translation>
    </message>
    <message>
        <location filename="../src/BreakpointHitCountDialog.cpp" line="74"/>
        <source>OK</source>
        <translation>TAMAM</translation>
    </message>
    <message>
        <location filename="../src/BreakpointHitCountDialog.cpp" line="75"/>
        <source>Cancel</source>
        <translation>Vazgeç</translation>
    </message>
</context>
<context>
    <name>U2::ComboBoxWidget</name>
    <message>
        <location filename="../src/PropertyWidget.cpp" line="217"/>
        <source>False</source>
        <translation>Yanlış</translation>
    </message>
    <message>
        <location filename="../src/PropertyWidget.cpp" line="218"/>
        <source>True</source>
        <translation>Doğru</translation>
    </message>
</context>
<context>
    <name>U2::ComboBoxWithDbUrlWidget</name>
    <message>
        <location filename="../src/PropertyWidget.cpp" line="366"/>
        <source>Add New Connection</source>
        <translation>Yeni Bağlantı Ekle</translation>
    </message>
</context>
<context>
    <name>U2::ComboBoxWithUrlWidget</name>
    <message>
        <location filename="../src/PropertyWidget.cpp" line="343"/>
        <source>Select a folder</source>
        <translation>Bir klasör seçin</translation>
    </message>
    <message>
        <location filename="../src/PropertyWidget.cpp" line="348"/>
        <source>Select a file</source>
        <translation>Bir dosya seçin</translation>
    </message>
</context>
<context>
    <name>U2::CreateDirectoryDialog</name>
    <message>
        <location filename="../src/OutputFileDialog.cpp" line="210"/>
        <source>OK</source>
        <translation>TAMAM</translation>
    </message>
    <message>
        <location filename="../src/OutputFileDialog.cpp" line="211"/>
        <source>Cancel</source>
        <translation>Vazgeç</translation>
    </message>
</context>
<context>
    <name>U2::Dashboard</name>
    <message>
        <location filename="../src/dashboard/Dashboard.cpp" line="145"/>
        <source>Overview</source>
        <translation>Genel Görünüm</translation>
    </message>
    <message>
        <location filename="../src/dashboard/Dashboard.cpp" line="154"/>
        <source>Input</source>
        <translation>Giriş</translation>
    </message>
    <message>
        <location filename="../src/dashboard/Dashboard.cpp" line="162"/>
        <location filename="../src/dashboard/Dashboard.cpp" line="236"/>
        <source>External Tools</source>
        <translation>Dış Araçlar</translation>
    </message>
    <message>
        <location filename="../src/dashboard/Dashboard.cpp" line="181"/>
        <source>Open workflow schema</source>
        <translation>İş akışı şemasını aç</translation>
    </message>
    <message>
        <location filename="../src/dashboard/Dashboard.cpp" line="200"/>
        <source>Output files</source>
        <translation>Çıktı dosyaları</translation>
    </message>
    <message>
        <location filename="../src/dashboard/Dashboard.cpp" line="204"/>
        <source>Workflow task</source>
        <translation>İş akışı görevi</translation>
    </message>
    <message>
        <location filename="../src/dashboard/Dashboard.cpp" line="208"/>
        <source>Notifications</source>
        <translation>Bildirimler</translation>
    </message>
    <message>
        <location filename="../src/dashboard/Dashboard.cpp" line="213"/>
        <source>Common statistics</source>
        <translation>Ortak istatistikler</translation>
    </message>
    <message>
        <location filename="../src/dashboard/Dashboard.cpp" line="221"/>
        <source>Parameters</source>
        <translation>Parametreler</translation>
    </message>
    <message>
        <location filename="../src/dashboard/Dashboard.cpp" line="322"/>
        <source>Can not create a folder: </source>
        <translation>Klasör oluşturulamıyor: </translation>
    </message>
    <message>
        <location filename="../src/dashboard/Dashboard.cpp" line="328"/>
        <source>Failed to open Dashboard.html</source>
        <translation>Dashboard.html açılamadı</translation>
    </message>
    <message>
        <location filename="../src/dashboard/Dashboard.cpp" line="479"/>
        <source>Error reading dashboard file: %1</source>
        <translation>Gösterge tablosu dosyası okunurken hata oluştu: %1</translation>
    </message>
    <message>
        <location filename="../src/dashboard/Dashboard.cpp" line="491"/>
        <source>Error parsing dashboard file: &apos;%1&apos;, file: %2</source>
        <translation>Kontrol paneli dosyası ayrıştırılırken hata oluştu: &apos;%1&apos;, dosya: %2</translation>
    </message>
</context>
<context>
    <name>U2::DashboardFileButton</name>
    <message>
        <location filename="../src/dashboard/DashboardWidget.cpp" line="217"/>
        <source>%1 file(s)</source>
        <translation>%1 dosya</translation>
    </message>
    <message>
        <location filename="../src/dashboard/DashboardWidget.cpp" line="268"/>
        <source>Open file with UGENE</source>
        <translation>Dosyayı UGENE ile aç</translation>
    </message>
    <message>
        <location filename="../src/dashboard/DashboardWidget.cpp" line="274"/>
        <source>Open folder with the file</source>
        <translation>Dosyayla klasörü aç</translation>
    </message>
    <message>
        <location filename="../src/dashboard/DashboardWidget.cpp" line="279"/>
        <source>Open file by OS</source>
        <translation>Dosyayı işletim sistemine göre aç</translation>
    </message>
</context>
<context>
    <name>U2::DashboardInfoRegistry</name>
    <message>
        <location filename="../src/dashboard/DashboardInfoRegistry.cpp" line="139"/>
        <source>Can&apos;t register a dashboard info: &apos;%1&apos;</source>
        <translation>Gösterge tablosu bilgisi kaydedilemiyor: &apos;%1&apos;</translation>
    </message>
</context>
<context>
    <name>U2::DashboardWidget</name>
    <message>
        <location filename="../src/dashboard/DashboardWidget.cpp" line="337"/>
        <source>File is not found: %1</source>
        <translation>Dosya bulunamadı: %1</translation>
    </message>
</context>
<context>
    <name>U2::DatasetsController</name>
    <message>
        <location filename="../src/DatasetsController.cpp" line="169"/>
        <source>Dataset name is empty</source>
        <translation>Veri kümesi adı boş</translation>
    </message>
    <message>
        <location filename="../src/DatasetsController.cpp" line="173"/>
        <source>Dataset name can not contain &apos;:&apos; and &apos;;&apos; symbols</source>
        <translation>Veri kümesi adı &apos;:&apos; ve &apos;;&apos; semboller içeremez</translation>
    </message>
    <message>
        <location filename="../src/DatasetsController.cpp" line="178"/>
        <source>This dataset name already exists</source>
        <translation>Bu veri kümesi adı zaten var</translation>
    </message>
</context>
<context>
    <name>U2::DatasetsListWidget</name>
    <message>
        <location filename="../src/DatasetsListWidget.cpp" line="54"/>
        <source>Add dataset</source>
        <translation>Veri kümesi ekleyin</translation>
    </message>
    <message>
        <location filename="../src/DatasetsListWidget.cpp" line="98"/>
        <source>Enter Dataset Name</source>
        <translation>Veri Kümesi Adını Girin</translation>
    </message>
    <message>
        <location filename="../src/DatasetsListWidget.cpp" line="99"/>
        <location filename="../src/DatasetsListWidget.cpp" line="132"/>
        <source>New dataset name:</source>
        <translation>Yeni veri kümesi adı:</translation>
    </message>
    <message>
        <location filename="../src/DatasetsListWidget.cpp" line="110"/>
        <location filename="../src/DatasetsListWidget.cpp" line="142"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../src/DatasetsListWidget.cpp" line="131"/>
        <source>Rename Dataset</source>
        <translation>Veri Kümesini Yeniden Adlandırın</translation>
    </message>
    <message>
        <location filename="../src/DatasetsListWidget.cpp" line="152"/>
        <source>Rename dataset</source>
        <translation>Veri kümesini yeniden adlandırın</translation>
    </message>
</context>
<context>
    <name>U2::DbFolderItem</name>
    <message>
        <location filename="../src/DbFolderItem.cpp" line="41"/>
        <source>Use &lt;i&gt;right click&lt;/i&gt; to set advanced options</source>
        <translation>Gelişmiş seçenekleri ayarlamak için&lt;i&gt;sağ tıklamayı&lt;/i&gt;kullanın</translation>
    </message>
</context>
<context>
    <name>U2::DbObjectItem</name>
    <message>
        <location filename="../src/DbObjectItem.cpp" line="37"/>
        <source>&quot; is located in the database &lt;b&gt;</source>
        <translation>&quot;, &lt;b&gt;veritabanında bulunur</translation>
    </message>
</context>
<context>
    <name>U2::DirectoryItem</name>
    <message>
        <location filename="../src/DirectoryItem.cpp" line="36"/>
        <source>Use &lt;i&gt;right click&lt;/i&gt; to set advanced options</source>
        <translation>Gelişmiş seçenekleri ayarlamak için&lt;i&gt;sağ tıklamayı&lt;/i&gt;kullanın</translation>
    </message>
</context>
<context>
    <name>U2::EditBreakpointLabelsDialog</name>
    <message>
        <location filename="../src/EditBreakpointLabelsDialog.cpp" line="48"/>
        <source>OK</source>
        <translation>TAMAM</translation>
    </message>
    <message>
        <location filename="../src/EditBreakpointLabelsDialog.cpp" line="49"/>
        <source>Cancel</source>
        <translation>Vazgeç</translation>
    </message>
</context>
<context>
    <name>U2::EditMarkerDialog</name>
    <message>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="403"/>
        <source>OK</source>
        <translation>TAMAM</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="404"/>
        <source>Cancel</source>
        <translation>Vazgeç</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="412"/>
        <source>Create Marker</source>
        <translation>İşaretçi Oluştur</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="450"/>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="455"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
</context>
<context>
    <name>U2::EditMarkerGroupDialog</name>
    <message>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="47"/>
        <source>OK</source>
        <translation>TAMAM</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="48"/>
        <source>Cancel</source>
        <translation>Vazgeç</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="87"/>
        <source>Create Marker Group</source>
        <translation>İşaretleyici Grubu Oluştur</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="190"/>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="291"/>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="298"/>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="303"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="190"/>
        <source>You can not remove the required marker &quot;rest&quot;</source>
        <translation>Gerekli &quot;dinlenme&quot; işaretini kaldıramazsınız</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="209"/>
        <source>Warning</source>
        <translation>Uyarı</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="209"/>
        <source>Are you really want to change marker&apos;s type? Some data can be lost!</source>
        <translation>İşaretçinin türünü gerçekten değiştirmek istiyor musunuz? Bazı veriler kaybolabilir!</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="241"/>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="265"/>
        <source>Marker&apos;s name contains a comma symbol: &quot;%1&quot;. It is not permitted for marker names</source>
        <translation>İşaretçinin adı virgül simgesi içeriyor: &quot;%1&quot;. İşaret isimleri için izin verilmez</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="247"/>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="270"/>
        <source>Duplicate marker&apos;s value: %1</source>
        <translation>Yinelenen işaretleyicinin değeri: %1</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="254"/>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="275"/>
        <source>Duplicate marker&apos;s name: %1</source>
        <translation>Yinelenen işaretçinin adı: %1</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="291"/>
        <source>Parameter &apos;%1&apos; is not set</source>
        <translation>&apos;%1&apos; parametresi ayarlanmadı</translation>
    </message>
</context>
<context>
    <name>U2::GroupBox</name>
    <message>
        <location filename="../src/wizard/WizardController.cpp" line="911"/>
        <source>Show</source>
        <translation>Göster</translation>
    </message>
    <message>
        <location filename="../src/wizard/WizardController.cpp" line="916"/>
        <source>Hide</source>
        <translation>Gizle</translation>
    </message>
    <message>
        <location filename="../src/wizard/WizardController.cpp" line="936"/>
        <source>additional</source>
        <translation>ek</translation>
    </message>
    <message>
        <location filename="../src/wizard/WizardController.cpp" line="940"/>
        <source> settings</source>
        <translation> ayarlar</translation>
    </message>
</context>
<context>
    <name>U2::GrouperEditorWidget</name>
    <message>
        <location filename="../src/GrouperEditorWidget.cpp" line="75"/>
        <source>&lt;Unset&gt;</source>
        <translation>&lt;Unset&gt;</translation>
    </message>
    <message>
        <location filename="../src/GrouperEditorWidget.cpp" line="111"/>
        <source>By value</source>
        <translation>Değere göre</translation>
    </message>
    <message>
        <location filename="../src/GrouperEditorWidget.cpp" line="117"/>
        <source>By id</source>
        <translation>Kimliğe göre</translation>
    </message>
    <message>
        <location filename="../src/GrouperEditorWidget.cpp" line="118"/>
        <source>By name</source>
        <translation>İsimle</translation>
    </message>
</context>
<context>
    <name>U2::GrouperSlotsCfgModel</name>
    <message>
        <location filename="../src/GrouperEditorWidget.cpp" line="300"/>
        <source>Output slot name</source>
        <translation>Çıkış yuvası adı</translation>
    </message>
    <message>
        <location filename="../src/GrouperEditorWidget.cpp" line="302"/>
        <source>Source data slot</source>
        <translation>Kaynak veri yuvası</translation>
    </message>
</context>
<context>
    <name>U2::MarkerEditorWidget</name>
    <message>
        <location filename="../src/MarkerEditorWidget.cpp" line="123"/>
        <location filename="../src/MarkerEditorWidget.cpp" line="138"/>
        <source>Duplicate marker&apos;s name: %1</source>
        <translation>Yinelenen işaretçinin adı: %1</translation>
    </message>
    <message>
        <location filename="../src/MarkerEditorWidget.cpp" line="145"/>
        <source>Marker&apos;s name contains spaces: %1</source>
        <translation>İşaretçinin adı boşluklar içeriyor: %1</translation>
    </message>
</context>
<context>
    <name>U2::MarkerListCfgModel</name>
    <message>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="350"/>
        <source>Marker name</source>
        <translation>İşaretleyici adı</translation>
    </message>
    <message>
        <location filename="../src/EditMarkerGroupDialog.cpp" line="352"/>
        <source>Marker value</source>
        <translation>İşaretleyici değeri</translation>
    </message>
</context>
<context>
    <name>U2::MsaActionDialog</name>
    <message>
        <location filename="../src/NewGrouperSlotDialog.cpp" line="216"/>
        <source>OK</source>
        <translation>TAMAM</translation>
    </message>
    <message>
        <location filename="../src/NewGrouperSlotDialog.cpp" line="217"/>
        <source>Cancel</source>
        <translation>Vazgeç</translation>
    </message>
</context>
<context>
    <name>U2::NewBreakpointDialog</name>
    <message>
        <location filename="../src/NewBreakpointDialog.cpp" line="36"/>
        <source>OK</source>
        <translation>TAMAM</translation>
    </message>
    <message>
        <location filename="../src/NewBreakpointDialog.cpp" line="37"/>
        <source>Cancel</source>
        <translation>Vazgeç</translation>
    </message>
</context>
<context>
    <name>U2::NewGrouperSlotDialog</name>
    <message>
        <location filename="../src/NewGrouperSlotDialog.cpp" line="39"/>
        <source>OK</source>
        <translation>TAMAM</translation>
    </message>
    <message>
        <location filename="../src/NewGrouperSlotDialog.cpp" line="40"/>
        <source>Cancel</source>
        <translation>Vazgeç</translation>
    </message>
    <message>
        <location filename="../src/NewGrouperSlotDialog.cpp" line="53"/>
        <source>Empty output slot name.</source>
        <translation>Boş çıktı yuvası adı.</translation>
    </message>
    <message>
        <location filename="../src/NewGrouperSlotDialog.cpp" line="55"/>
        <source>Invalid symbols in the output slot name. Use letters and digits only.</source>
        <translation>Çıktı yuvası adında geçersiz simgeler. Yalnızca harf ve rakam kullanın.</translation>
    </message>
    <message>
        <location filename="../src/NewGrouperSlotDialog.cpp" line="57"/>
        <source>This output out slot already exists.</source>
        <translation>Bu çıkış yuvası zaten var.</translation>
    </message>
    <message>
        <location filename="../src/NewGrouperSlotDialog.cpp" line="63"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
</context>
<context>
    <name>U2::NotificationsDashboardWidget</name>
    <message>
        <location filename="../src/dashboard/NotificationsDashboardWidget.cpp" line="68"/>
        <location filename="../src/dashboard/NotificationsDashboardWidget.cpp" line="128"/>
        <source>Type</source>
        <translation>Tür</translation>
    </message>
    <message>
        <location filename="../src/dashboard/NotificationsDashboardWidget.cpp" line="68"/>
        <location filename="../src/dashboard/NotificationsDashboardWidget.cpp" line="128"/>
        <source>Element</source>
        <translation>Öğe</translation>
    </message>
    <message>
        <location filename="../src/dashboard/NotificationsDashboardWidget.cpp" line="68"/>
        <location filename="../src/dashboard/NotificationsDashboardWidget.cpp" line="128"/>
        <source>Message</source>
        <translation>İleti</translation>
    </message>
</context>
<context>
    <name>U2::OutputDirectoryWidget</name>
    <message>
        <location filename="../src/support/OutputDirectoryWidget.cpp" line="43"/>
        <source>The Workflow Output Folder is a common folder that is used to store all output files in the Workflow Designer. A separate subdirectory of the folder is created for each run of a workflow.

Set up the folder:</source>
        <translation>İş Akışı Çıktı Klasörü, tüm çıktı dosyalarını İş Akışı Tasarımcısı&apos;nda depolamak için kullanılan ortak bir klasördür. Bir iş akışının her çalıştırması için klasörün ayrı bir alt dizini oluşturulur.

Klasörü ayarlayın:</translation>
    </message>
    <message>
        <location filename="../src/support/OutputDirectoryWidget.cpp" line="68"/>
        <source>Select a folder</source>
        <translation>Bir klasör seçin</translation>
    </message>
</context>
<context>
    <name>U2::OutputFileDialog</name>
    <message>
        <location filename="../src/OutputFileDialog.cpp" line="50"/>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <location filename="../src/OutputFileDialog.cpp" line="51"/>
        <source>Cancel</source>
        <translation>Vazgeç</translation>
    </message>
    <message>
        <location filename="../src/OutputFileDialog.cpp" line="55"/>
        <source>Save a folder</source>
        <translation>Klasöre kaydet</translation>
    </message>
    <message>
        <location filename="../src/OutputFileDialog.cpp" line="57"/>
        <source>Save a file</source>
        <translation>Dosyaya kaydet</translation>
    </message>
</context>
<context>
    <name>U2::OutputFilesDashboardWidget</name>
    <message>
        <location filename="../src/dashboard/OutputFilesDashboardWidget.cpp" line="76"/>
        <location filename="../src/dashboard/OutputFilesDashboardWidget.cpp" line="151"/>
        <source>File</source>
        <translation>Dosya</translation>
    </message>
    <message>
        <location filename="../src/dashboard/OutputFilesDashboardWidget.cpp" line="76"/>
        <location filename="../src/dashboard/OutputFilesDashboardWidget.cpp" line="151"/>
        <source>Producer</source>
        <translation>Üretici</translation>
    </message>
</context>
<context>
    <name>U2::ParametersDashboardWidget</name>
    <message>
        <location filename="../src/dashboard/ParametersDashboardWidget.cpp" line="217"/>
        <location filename="../src/dashboard/ParametersDashboardWidget.cpp" line="283"/>
        <source>Parameter</source>
        <translation>Parametre</translation>
    </message>
    <message>
        <location filename="../src/dashboard/ParametersDashboardWidget.cpp" line="217"/>
        <location filename="../src/dashboard/ParametersDashboardWidget.cpp" line="283"/>
        <source>Value</source>
        <translation>Değer</translation>
    </message>
</context>
<context>
    <name>U2::QDCreateAnnotationsTask</name>
    <message>
        <location filename="../src/QDScheduler.h" line="196"/>
        <source>Prepare annotations task</source>
        <translation>Ek açıklamalar görevi hazırlayın</translation>
    </message>
</context>
<context>
    <name>U2::QDFindLocationTask</name>
    <message>
        <location filename="../src/QDScheduler.h" line="138"/>
        <source>Find resultLocation</source>
        <translation>Sonuç bul</translation>
    </message>
</context>
<context>
    <name>U2::QDLinkResultsTask</name>
    <message>
        <location filename="../src/QDScheduler.h" line="163"/>
        <source>Link results</source>
        <translation>Sonuçları bağla</translation>
    </message>
</context>
<context>
    <name>U2::QDScheduler</name>
    <message>
        <location filename="../src/QDScheduler.cpp" line="47"/>
        <source>QDScheduler</source>
        <translation>QDScheduler</translation>
    </message>
    <message>
        <location filename="../src/QDScheduler.cpp" line="70"/>
        <source>Can&apos;t find annotation object: %1 in document: %2</source>
        <translation>Ek açıklama nesnesi bulunamıyor: %1, dokümanda: %2</translation>
    </message>
    <message>
        <location filename="../src/QDScheduler.cpp" line="103"/>
        <source>Annotation object is not available</source>
        <translation>Ek açıklama nesnesi mevcut değil</translation>
    </message>
    <message>
        <location filename="../src/QDScheduler.cpp" line="152"/>
        <source>Invalid applications settings detected</source>
        <translation>Geçersiz uygulama ayarları algılandı</translation>
    </message>
    <message>
        <location filename="../src/QDScheduler.cpp" line="155"/>
        <source>Invalid users applications settings detected</source>
        <translation>Geçersiz kullanıcı uygulama ayarları algılandı</translation>
    </message>
    <message>
        <location filename="../src/QDScheduler.cpp" line="361"/>
        <source>No results have been found for this scheme</source>
        <translation>Bu şema için sonuç bulunamadı</translation>
    </message>
    <message>
        <location filename="../src/QDScheduler.cpp" line="478"/>
        <source>Too many results have been found for this scheme. Try to set stricter search conditions.</source>
        <translation>Bu şema için çok fazla sonuç bulundu. Daha katı arama koşulları oluşturmaya çalışın.</translation>
    </message>
</context>
<context>
    <name>U2::QDTask</name>
    <message>
        <location filename="../src/QDScheduler.cpp" line="749"/>
        <source>Query task: %1</source>
        <translation>Sorgu görevi: %1
1</translation>
    </message>
</context>
<context>
    <name>U2::RemoveDashboardsTask</name>
    <message>
        <location filename="../src/dashboard/RemoveDashboardsTask.cpp" line="30"/>
        <source>Remove dashboards</source>
        <translation>Gösterge tablolarını kaldır</translation>
    </message>
</context>
<context>
    <name>U2::ScanDashboardsDirTask</name>
    <message>
        <location filename="../src/dashboard/ScanDashboardsDirTask.cpp" line="36"/>
        <source>Scan dashboards folder</source>
        <translation>Gösterge tabloları klasörünü tara</translation>
    </message>
</context>
<context>
    <name>U2::SchemaRunModeDelegate</name>
    <message>
        <location filename="../src/DelegateEditors.cpp" line="596"/>
        <source>This computer</source>
        <translation>Bu bilgisayar</translation>
    </message>
    <message>
        <location filename="../src/DelegateEditors.cpp" line="597"/>
        <source>Remote computer</source>
        <translation>Uzak bilgisayar</translation>
    </message>
</context>
<context>
    <name>U2::SequeceActionDialog</name>
    <message>
        <location filename="../src/NewGrouperSlotDialog.cpp" line="152"/>
        <source>OK</source>
        <translation>TAMAM</translation>
    </message>
    <message>
        <location filename="../src/NewGrouperSlotDialog.cpp" line="153"/>
        <source>Cancel</source>
        <translation>Vazgeç</translation>
    </message>
</context>
<context>
    <name>U2::StatisticsDashboardWidget</name>
    <message>
        <location filename="../src/dashboard/StatisticsDashboardWidget.cpp" line="64"/>
        <location filename="../src/dashboard/StatisticsDashboardWidget.cpp" line="77"/>
        <source>Element</source>
        <translation>Öğe</translation>
    </message>
    <message>
        <location filename="../src/dashboard/StatisticsDashboardWidget.cpp" line="64"/>
        <location filename="../src/dashboard/StatisticsDashboardWidget.cpp" line="77"/>
        <source>Elapsed time</source>
        <translation>Geçen zaman</translation>
    </message>
    <message>
        <location filename="../src/dashboard/StatisticsDashboardWidget.cpp" line="64"/>
        <location filename="../src/dashboard/StatisticsDashboardWidget.cpp" line="77"/>
        <source>Output messages</source>
        <translation>Çıktı mesajları</translation>
    </message>
</context>
<context>
    <name>U2::StatusDashboardWidget</name>
    <message>
        <location filename="../src/dashboard/StatusDashboardWidget.cpp" line="80"/>
        <location filename="../src/dashboard/StatusDashboardWidget.cpp" line="147"/>
        <source>Time %1</source>
        <translation>Zaman %1</translation>
    </message>
    <message>
        <location filename="../src/dashboard/StatusDashboardWidget.cpp" line="157"/>
        <source>The workflow task is in progress…</source>
        <translation>İş akışı görevi devam ediyor…</translation>
    </message>
    <message>
        <location filename="../src/dashboard/StatusDashboardWidget.cpp" line="159"/>
        <source>The workflow task is in progress. There are problems…</source>
        <translation>İş akışı görevi devam ediyor. Problemler var…</translation>
    </message>
    <message>
        <location filename="../src/dashboard/StatusDashboardWidget.cpp" line="161"/>
        <source>The workflow task has been finished with warnings!</source>
        <translation>İş akışı görevi uyarılarla tamamlandı!</translation>
    </message>
    <message>
        <location filename="../src/dashboard/StatusDashboardWidget.cpp" line="163"/>
        <source>The workflow task has been finished with errors!</source>
        <translation>İş akışı görevi hatalarla tamamlandı!</translation>
    </message>
    <message>
        <location filename="../src/dashboard/StatusDashboardWidget.cpp" line="165"/>
        <source>The workflow task has been finished successfully!</source>
        <translation>İş akışı görevi başarıyla tamamlandı!</translation>
    </message>
    <message>
        <location filename="../src/dashboard/StatusDashboardWidget.cpp" line="167"/>
        <source>The workflow task has been canceled!</source>
        <translation>İş akışı görevi iptal edildi!</translation>
    </message>
</context>
<context>
    <name>U2::StringActionDialog</name>
    <message>
        <location filename="../src/NewGrouperSlotDialog.cpp" line="249"/>
        <source>OK</source>
        <translation>TAMAM</translation>
    </message>
    <message>
        <location filename="../src/NewGrouperSlotDialog.cpp" line="250"/>
        <source>Cancel</source>
        <translation>Vazgeç</translation>
    </message>
</context>
<context>
    <name>U2::StringListDelegate</name>
    <message>
        <location filename="../src/DelegateEditors.cpp" line="722"/>
        <source>Enter items</source>
        <translation>Öğeleri girin</translation>
    </message>
    <message>
        <location filename="../src/DelegateEditors.cpp" line="724"/>
        <source>OK</source>
        <translation>TAMAM</translation>
    </message>
    <message>
        <location filename="../src/DelegateEditors.cpp" line="726"/>
        <source>Cancel</source>
        <translation>Vazgeç</translation>
    </message>
</context>
<context>
    <name>U2::TophatSamples</name>
    <message>
        <location filename="../src/wizard/TophatSamplesWidgetController.cpp" line="280"/>
        <source>Divide the input datasets into samples for running Cuffdiff. There are must be at least 2 samples. It is not necessary to have the same number of datasets (replicates) for each sample. The samples names will be used by Cuffdiff as labels, which will be included in various output files produced by Cuffdiff.</source>
        <translation>Cuffdiff&apos;i çalıştırmak için giriş veri setlerini örneklere bölün. En az 2 numune olmalıdır. Her numune için aynı sayıda veri setine (tekrar) sahip olmak gerekli değildir. Örnek isimleri Cuffdiff tarafından etiket olarak kullanılacaktır ve bunlar Cuffdiff tarafından üretilen çeşitli çıktı dosyalarına dahil edilecektir.</translation>
    </message>
    <message>
        <location filename="../src/wizard/TophatSamplesWidgetController.cpp" line="358"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
</context>
<context>
    <name>U2::TophatSamplesWidgetController</name>
    <message>
        <location filename="../src/wizard/TophatSamplesWidgetController.cpp" line="59"/>
        <source>Sample name can not be empty</source>
        <translation>Örnek adı boş olamaz</translation>
    </message>
    <message>
        <location filename="../src/wizard/TophatSamplesWidgetController.cpp" line="64"/>
        <source>Sample name can consist only of Latin letters, numbers and the &apos;_&apos; symbol</source>
        <translation>Örnek adı yalnızca Latin harfleri, sayılar ve &apos;_&apos; sembolünden oluşabilir</translation>
    </message>
    <message>
        <location filename="../src/wizard/TophatSamplesWidgetController.cpp" line="72"/>
        <source>Duplicate sample name</source>
        <translation>Yinelenen örnek adı</translation>
    </message>
</context>
<context>
    <name>U2::URLLineEdit</name>
    <message>
        <location filename="../src/support/URLLineEdit.cpp" line="185"/>
        <source>Select a folder</source>
        <translation>Bir klasör seçin</translation>
    </message>
    <message>
        <location filename="../src/support/URLLineEdit.cpp" line="203"/>
        <location filename="../src/support/URLLineEdit.cpp" line="208"/>
        <location filename="../src/support/URLLineEdit.cpp" line="211"/>
        <source>Select a file</source>
        <translation>Bir dosya seçin</translation>
    </message>
    <message>
        <location filename="../src/support/URLLineEdit.cpp" line="188"/>
        <source>Select file(s)</source>
        <translation>Dosyaları seçin</translation>
    </message>
</context>
<context>
    <name>U2::URLListController</name>
    <message>
        <location filename="../src/DatasetsController.cpp" line="767"/>
        <source>This file or folder does not exist: %1</source>
        <translation>Bu dosya veya klasör mevcut değil: %1</translation>
    </message>
</context>
<context>
    <name>U2::URLListWidget</name>
    <message>
        <location filename="../src/DatasetWidget.cpp" line="117"/>
        <location filename="../src/DatasetWidget.cpp" line="119"/>
        <source>Select file</source>
        <translation>Dosya seçin</translation>
    </message>
    <message>
        <location filename="../src/DatasetWidget.cpp" line="129"/>
        <source>Select a folder</source>
        <translation>Bir klasör seçin</translation>
    </message>
    <message>
        <location filename="../src/DatasetWidget.cpp" line="197"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
</context>
<context>
    <name>U2::URLWidget</name>
    <message>
        <location filename="../src/PropertyWidget.cpp" line="521"/>
        <source>add</source>
        <translation>ekle</translation>
    </message>
</context>
<context>
    <name>U2::WizardController</name>
    <message>
        <location filename="../src/wizard/WizardController.cpp" line="100"/>
        <source>Apply</source>
        <translation>Uygula</translation>
    </message>
    <message>
        <location filename="../src/wizard/WizardController.cpp" line="122"/>
        <source>Defaults</source>
        <translation>Varsayılanlar</translation>
    </message>
    <message>
        <location filename="../src/wizard/WizardController.cpp" line="123"/>
        <source>Set page values by default</source>
        <translation>Varsayılan olarak sayfa değerlerini ayarlayın</translation>
    </message>
    <message>
        <location filename="../src/wizard/WizardController.cpp" line="128"/>
        <source>Run</source>
        <translation>Çalıştır</translation>
    </message>
</context>
<context>
    <name>U2::Workflow::MarkerGroupListCfgModel</name>
    <message>
        <location filename="../src/MarkerEditor.cpp" line="180"/>
        <source>Marker Group</source>
        <translation>İşaretleyici Grubu</translation>
    </message>
    <message>
        <location filename="../src/MarkerEditor.cpp" line="182"/>
        <source>Marker Value</source>
        <translation>İşaretleyici Değeri</translation>
    </message>
</context>
<context>
    <name>U2::WorkflowUtils</name>
    <message>
        <location filename="../src/DelegateEditors.cpp" line="584"/>
        <source>Overwrite</source>
        <translation>Üzerine Yaz</translation>
    </message>
    <message>
        <location filename="../src/DelegateEditors.cpp" line="585"/>
        <source>Rename</source>
        <translation>Yeniden adlandır</translation>
    </message>
    <message>
        <location filename="../src/DelegateEditors.cpp" line="587"/>
        <source>Append</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <location filename="../src/DesignerUtils.cpp" line="36"/>
        <source>UGENE workflow documents</source>
        <translation>UGENE iş akışı belgeleri</translation>
    </message>
</context>
<context>
    <name>U2::DashboardJsAgent</name>
    <message>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <source>The file does not exist</source>
        <translation>Dosya mevcut değil</translation>
    </message>
</context>
</TS>
